#define DEBUG_PRINT

#include <ctype.h>
#include <stdint.h>
#include <stdio.h>
#include <string.h>
#include <avr/io.h>
#include <util/delay.h>
#include "i2c.h"
#include "uart.h"

const char CMPS03_Addres = 0xC0;
const char  SRF08_Addres = 0xE0;
const char  I2CIT_Addres = 0x20;
const char switch_on  = 1;
const char switch_off = 0;


unsigned int CMPS03_get_angle(char address);
unsigned int  SRF08_get_range(char address);
unsigned char I2CIT_get_range(char address);

void debug_print(char* print_out);
void init_led (void);

void led_c5_on(void);
void led_c5_off(void);

void led_b3_on(void);
void led_b3_off(void);


//  UART          "uart.h"
FILE uart_str = FDEV_SETUP_STREAM(uart_putchar, uart_getchar, _FDEV_SETUP_RW);


int main(void)
{
unsigned int angle;
unsigned int range;
unsigned int ir_range;


init_led(); // Leds
i2c_init(); // I2C
uart_init(); // UART
stdout = stdin = &uart_str; //   \  UART
printf("OR - Started.\n");


//DDRD = 0x30; //5-6-   D   
//DDRB = 0x03; //0-1    B   


while(1) // 
{
debug_print("loop started...\n");
led_b3_on();
//led_c5_on();

angle = 0;
angle = CMPS03_get_angle(CMPS03_Addres);
if (angle != 0) led_c5_on(); // angle <> 0 lcd_c5 
printf("CMPS03 = %3d.%d\n",angle/10,angle%10); //  CMPS03  

_delay_ms(15250); // 0.25 
range = SRF08_get_range(SRF08_Addres);
printf("US Range: %d\n",range); //  SRF08  

ir_range = I2CIT_get_range(I2CIT_Addres);
printf("IR Range: %d\n",ir_range); //  I2CIT  


/*
PORTD &= ~0x30; // 5-6-   D  0
_delay_ms(15250); // 0.25 
PORTD |=  0x30; // 5-6-   D  1
*/
_delay_ms(15250); // 0.25 

led_c5_off();
led_b3_off();

/*
PORTD &= ~0x30; // 5-6-   D  0
_delay_ms(15250); // 0.25 
PORTD |=  0x30; // 5-6-   D  1
*/
_delay_ms(15250); // 0.25 

};

return 0;
}

void init_led (void)
{
MCUCSR |= 0x80; // JTAG,     PC5
MCUCSR |= 0x80;

DDRB = 0x08; //3   B   
DDRC = 0x20; //5   C   
};

void led_c5_on(void)
{
PORTC |= (1 << 5);
};

void led_c5_off(void)
{
PORTC &= ~(1 << 5);
};

void led_b3_on(void)
{
PORTB |= (1 << 3);
};

void led_b3_off(void)
{
PORTB &= ~(1 << 3);
};

unsigned int SRF08_get_range(char address)
{
unsigned int us_range;
i2c_transmit(address,0,0x51); //     ,     
debug_print("SRF08_get_range transmited\n");
_delay_ms(70); //  70,    
us_range = i2c_read(address,2) <<8; //    
debug_print("First byte\n");
us_range += i2c_read(address,3); //    
debug_print("Second byte\n");
return us_range;
};


unsigned int CMPS03_get_angle(char address)
{
unsigned int dc_angle;
dc_angle = i2c_read(address,2) <<8; //    
dc_angle += i2c_read(address,3); //    
return dc_angle;
};


unsigned char I2CIT_get_range(char address)
{
 unsigned char ir_range;

 debug_print("I2CIT_get_range started...\n");
 i2c_transmit(address,0, 2); //      
 debug_print("i2c_transmit transmited...\n");
 ir_range = i2c_read(address,0); //  
 debug_print("ir_range readed...\n");
 return ir_range;
};

void debug_print(char* print_out)
{
#ifdef DEBUG_PRINT
  printf(print_out);
#endif
};
